@@ -1,11 +1,16 @@
 """
-@time: 2022/8/5 15:00
-@desc
 
-Python Date Tools
+@productname：PyCharm
+@projectname：datedays
+@filename：datedays
+@time: 2022/8/5 15:00
+@author：liang1024
+@desc：
 
 datedays
 
+Python Date Tools
+
 What can it do?
 1. Get common date data
 2. Operating excel report
@@ -16,17 +21,19 @@ I hope it can help you
             --liang1024
 
 """
-
-__author__ = 'liang1024'
 __email__ = "chinalzge@gmail.com"
+__author__ = 'liang1024'
 
+import base64
 import calendar
+import datetime
 import random
 import string
 import time
 import traceback
 import uuid
 from datetime import date
+from urllib.parse import urlencode, quote, unquote
 
 import openpyxl
 import xlrd
@@ -80,6 +87,17 @@ def getdays(number=3):
     return _days
 
 
+def getasctime(t=None):
+    '''
+
+    :param t: specify timestamp
+    :return: such as Wed Aug 17 08:54:46 2022
+    '''
+    if t:
+        time.asctime(time.gmtime(t))
+    return time.asctime()
+
+
 def getnowtimestamp(t=1000):
     '''
     :param t:
@@ -148,12 +166,12 @@ def getnextdays(today=None, next_months=1):
     return _list
 
 
-def getstr2timestamp(date_str, format_='%Y-%m-%d'):
+def getstr2timestamp(date_str, format_='%Y-%m-%d %H:%M:%S'):
     '''
-    %Y-%m-%d %H:%M:%S
+    string to timestamp
 
-    :param date_str: for example 2022-08-15
-    :param format_: for example '%Y-%m-%d'
+    :param date_str: such as 2022-08-17 16:34:24
+    :param format_: such as %Y-%m-%d %H:%M:%S
     :return: timestamp
     '''
     return int(time.mktime(time.strptime(date_str, format_)))
@@ -162,7 +180,7 @@ def getstr2timestamp(date_str, format_='%Y-%m-%d'):
 def getcurrent_days(current_date=None):
     '''
     old function
-    recommended datedays.get_todaydays()
+    recommended datedays.gettodaydays()
 
     :param current_date:'%Y-%m-%d'
     :return:
@@ -173,7 +191,7 @@ def getcurrent_days(current_date=None):
 def getnext_days(current_date=None, next_months=1):
     '''
     old function
-    recommended datedays.get_nextdays()
+    recommended datedays.getnextdays()
 
     :param current_date: '%Y-%m-%d'
     :param next_months:
@@ -498,3 +516,84 @@ def getrandompassword(k=12, more_characters=None, _=string.ascii_letters + strin
     if k > len(_):
         k = len(_)
     return ''.join(random.sample(_, k))
+
+
+def gettimestamp2str(timestamp):
+    '''
+    timestamp to string
+
+    :param timestamp:  such as 1660726667690
+    :return: %Y-%m-%d %H:%M:%S
+    '''
+    return datetime.datetime.fromtimestamp(float(timestamp))
+
+
+def base64_encode(s, urlsafe=False):
+    if urlsafe:
+        return base64.urlsafe_b64encode(s)
+    return base64.b64encode(s)
+
+
+def base64_decode(s, urlsafe=False):
+    if urlsafe:
+        return base64.urlsafe_b64decode(s)
+    return base64.b64decode(s).decode('utf-8')
+
+
+def urlencodes(body):
+    if isinstance(body, dict):
+        return urlencode(body)
+    return quote(str(body))
+
+
+def urldecodes(body):
+    return unquote(body)
+
+
+def getstartend(start_date, end_date=date.today(), list_=False):
+    '''
+    get interval days or days list
+
+    :param start_date: %Y-%m-%d
+    :param end_date: %Y-%m-%d , default today
+    :param list_: datelist
+    :return:
+    '''
+
+    s_ = [int(_) for _ in str(start_date).split('-')]
+    e_ = [int(_) for _ in str(end_date).split('-')]
+    s_d = date(s_[0], s_[1], s_[2])
+    days = (date(e_[0], e_[1], e_[2]) - s_d).days
+    if list_:
+        return [(s_d + datetime.timedelta(days=_)).strftime('%Y-%m-%d') for _ in range(days + 1)]
+    return days
+
+
+def headers2dict(headers_string):
+    '''
+    copy headers string convert dict
+    :param headers_string:
+    :return:
+    '''
+    _dict = {}
+    if headers_string:
+        for h in [h if len(h) == 2 else None for h in [h.split(':', 1) for h in headers_string.splitlines()]]:
+            if h:
+                _dict[h[0].strip()] = h[1].strip()
+    return _dict
+
+
+if __name__ == '__main__':
+    print(headers2dict('''
+    Accept: application/json, text/javascript, */*; q=0.01
+    Accept-Encoding: gzip, deflate, br
+    Accept-Language: zh-CN,zh;q=0.9
+    Cache-Control: no-cache
+    Connection: keep-alive
+    Content-Type: application/x-www-form-urlencoded; charset=UTF-8
+    Pragma: no-cache
+    Sec-Fetch-Mode: cors
+    Sec-Fetch-Site: same-origin
+    User-Agent: Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/78.0.3904.108 Safari/537.36
+    X-Requested-With: XMLHttpRequest
+    '''))
